@@ -22,7 +22,7 @@ def start_transition(button, action):
         
 def open_article(button, url):
     global view_chain
-    art = nyt.get_text(url)
+    art = nyt.get_article(url)
     aview = article_view(art)
     view_chain.append(aview)
     top.set_body(aview)
@@ -42,7 +42,7 @@ def handle_keypress(key):
     if key == 'k':
         top.get_body().keypress((100, 50), 'up')
 
-    if key == 'l':
+    if key == 'l' or key == 'right':
         top.get_body().keypress((100, 50), 'enter')
     
     if key == 'left' or key == 'h':
