@@ -1,5 +1,5 @@
 from .search import search
 from .most_popular import most_popular
-from .article import get_text
+from .article import get_article
 from .newest import newest
 from .auth import keys_file_exists
